# Generated by roxygen2: do not edit by hand

S3method(plot,ascfcd)
S3method(plot,ascfcd_entities)
S3method(plot,ascfcd_pw)
S3method(plot,ascfcd_transitions)
S3method(print,ascfcd)
S3method(print,ascfcd_base)
S3method(print,ascfcd_entities)
S3method(print,ascfcd_pw)
S3method(print,ascfcd_space)
S3method(print,ascfcd_transitions)
S3method(summary,ascfcd)
S3method(summary,ascfcd_base)
S3method(summary,ascfcd_entities)
S3method(summary,ascfcd_pw)
S3method(summary,ascfcd_space)
S3method(summary,ascfcd_transitions)
export(asc_baseline)
export(asc_entities)
export(asc_null)
export(asc_paired)
export(asc_pairwise)
export(asc_transitions)
export(assess_functional_space)
import(ggplot2)
importFrom(stats,sd)
importFrom(stats,simulate)
importFrom(vegan,nullmodel)
